Index: code/branches/gamestates2/data/gui/scripts/AudioMenu.lua
===================================================================
--- code/branches/gamestates2/data/gui/scripts/AudioMenu.lua	(revision 6721)
+++ code/branches/gamestates2/data/gui/scripts/AudioMenu.lua	(revision 6722)
@@ -169,5 +169,5 @@
 
 function P.AudioBackButton_clicked(e)
-    hideGUI(P.name)
+    hideMenuSheet(P.name)
 end
 
Index: code/branches/gamestates2/data/gui/scripts/ControlsMenu.lua
===================================================================
--- code/branches/gamestates2/data/gui/scripts/ControlsMenu.lua	(revision 6721)
+++ code/branches/gamestates2/data/gui/scripts/ControlsMenu.lua	(revision 6722)
@@ -4,13 +4,13 @@
 
 function P.ControlsMouseControlsButton_clicked(e)
-    showGUI("MouseControlsMenu", true)
+    showMenuSheet("MouseControlsMenu", true)
 end
 
 function P.ControlsKeyboardControlsButton_clicked(e)
-    showGUI("KeyBindMenu", true)
+    showMenuSheet("KeyBindMenu", true)
 end
 
 function P.ControlsBackButton_clicked(e)
-    hideGUI(P.name)
+    hideMenuSheet(P.name)
 end
 
Index: code/branches/gamestates2/data/gui/scripts/CreditsMenu.lua
===================================================================
--- code/branches/gamestates2/data/gui/scripts/CreditsMenu.lua	(revision 6721)
+++ code/branches/gamestates2/data/gui/scripts/CreditsMenu.lua	(revision 6722)
@@ -4,5 +4,5 @@
 
 function P.CreditsBackButton_clicked(e)
-    hideGUI(P.name)
+    hideMenuSheet(P.name)
 end
 
Index: code/branches/gamestates2/data/gui/scripts/DecisionPopup.lua
===================================================================
--- code/branches/gamestates2/data/gui/scripts/DecisionPopup.lua	(revision 6721)
+++ code/branches/gamestates2/data/gui/scripts/DecisionPopup.lua	(revision 6722)
@@ -16,5 +16,5 @@
         P.functionPtr(true)
     end
-    hideGUI("DecisionPopup")
+    hideMenuSheet("DecisionPopup")
 end
 
@@ -23,5 +23,5 @@
         P.functionPtr(false)
     end
-    hideGUI("DecisionPopup")
+    hideMenuSheet("DecisionPopup")
 end
 
Index: code/branches/gamestates2/data/gui/scripts/GUITools.lua
===================================================================
--- code/branches/gamestates2/data/gui/scripts/GUITools.lua	(revision 6721)
+++ code/branches/gamestates2/data/gui/scripts/GUITools.lua	(revision 6722)
@@ -15,5 +15,5 @@
 
 function openDecisionPopup( text, callbackPtr )
-    showGUI("DecisionPopup", false, true)
+    showMenuSheet("DecisionPopup", false, true)
     DecisionPopup.setCallback(callbackPtr)
     DecisionPopup.setText(text)
@@ -21,5 +21,5 @@
 
 function openInfoPopup(text, functionPtr, closeButton, arguments)
-    showGUI("InfoPopup", false, true)
+    showMenuSheet("InfoPopup", false, true)
     InfoPopup.execute(functionPtr, arguments)
     InfoPopup.setText(text)
Index: code/branches/gamestates2/data/gui/scripts/GameplayMenu.lua
===================================================================
--- code/branches/gamestates2/data/gui/scripts/GameplayMenu.lua	(revision 6721)
+++ code/branches/gamestates2/data/gui/scripts/GameplayMenu.lua	(revision 6722)
@@ -37,5 +37,5 @@
 
 function P.GameplayBackButton_clicked(e)
-    hideGUI(P.name)
+    hideMenuSheet(P.name)
 end
 
Index: code/branches/gamestates2/data/gui/scripts/GraphicsMenu.lua
===================================================================
--- code/branches/gamestates2/data/gui/scripts/GraphicsMenu.lua	(revision 6721)
+++ code/branches/gamestates2/data/gui/scripts/GraphicsMenu.lua	(revision 6722)
@@ -192,5 +192,5 @@
 
 function P.GraphicsBackButton_clicked(e)
-    hideGUI(P.name)
+    hideMenuSheet(P.name)
 end
 
Index: code/branches/gamestates2/data/gui/scripts/InGameMenu.lua
===================================================================
--- code/branches/gamestates2/data/gui/scripts/InGameMenu.lua	(revision 6721)
+++ code/branches/gamestates2/data/gui/scripts/InGameMenu.lua	(revision 6722)
@@ -12,18 +12,18 @@
     orxonox.Game:getInstance():popState()
     orxonox.Game:getInstance():requestState("mainmenu")
-    hideGUI("InGameMenu")
+    hideMenuSheet("InGameMenu")
 end
 
 function P.button_settings_clicked(e)
-    showGUI("SettingsMenu", true)
+    showMenuSheet("SettingsMenu", true)
 end
 
 function P.button_return_clicked(e)
-    hideGUI("InGameMenu")
+    hideMenuSheet("InGameMenu")
 end
 
 function P.callback(doExit)
     if doExit then
-        hideGUI("InGameMenu")
+        hideMenuSheet("InGameMenu")
         orxonox.execute("exit")
     end
Index: code/branches/gamestates2/data/gui/scripts/InfoPopup.lua
===================================================================
--- code/branches/gamestates2/data/gui/scripts/InfoPopup.lua	(revision 6721)
+++ code/branches/gamestates2/data/gui/scripts/InfoPopup.lua	(revision 6722)
@@ -29,5 +29,5 @@
 -- events for ingamemenu
 function P.close(e)
-    hideGUI(P.name)
+    hideMenuSheet(P.name)
 end
 
Index: code/branches/gamestates2/data/gui/scripts/InitialiseGUI.lua
===================================================================
--- code/branches/gamestates2/data/gui/scripts/InitialiseGUI.lua	(revision 6721)
+++ code/branches/gamestates2/data/gui/scripts/InitialiseGUI.lua	(revision 6722)
@@ -75,6 +75,6 @@
 
 -- ?
-function showGUI(name, bHidePrevious, ptr)
-    local sheet = showGUI(name, bHidePrevious)
+function showMenuSheet(name, bHidePrevious, ptr)
+    local sheet = showMenuSheet(name, bHidePrevious)
     sheet.overlay = ptr
     return sheet
@@ -82,5 +82,5 @@
 
 -- Shows the specified menu sheet and loads it if neccessary
-function showGUI(name, bHidePrevious)
+function showMenuSheet(name, bHidePrevious)
     -- Get sheet (or load it)
     local menuSheet = loadSheet(name)
@@ -103,5 +103,5 @@
     -- Hide if already displayed (to make sure it is up front in the end)
     if activeMenuSheets[name] ~= nil then
-        hideGUI(name)
+        hideMenuSheet(name)
     end
 
@@ -146,5 +146,5 @@
 end
 
-function hideGUI(name)
+function hideMenuSheet(name)
     local sheetTuple = activeMenuSheets[name]
     if sheetTuple == nil then
@@ -206,7 +206,7 @@
 
 -- Hides all menu GUI sheets
-function hideAllGUIs()
+function hideAllMenuSheets()
     while activeMenuSheets.size ~= 0 do
-        hideGUI(activeMenuSheets.topSheetTuple.sheet.name)
+        hideMenuSheet(activeMenuSheets.topSheetTuple.sheet.name)
     end
 end
@@ -217,7 +217,7 @@
         orxonox.execute("exit")
     elseif activeMenuSheets.size > 0 then
-        orxonox.execute("hideGUI "..activeMenuSheets.topSheetTuple.sheet.name)
+        orxonox.execute("hideMenuSheet "..activeMenuSheets.topSheetTuple.sheet.name)
     else
-        showGUI("InGameMenu")
+        showMenuSheet("InGameMenu")
     end
 end
Index: code/branches/gamestates2/data/gui/scripts/KeyBindMenu.lua
===================================================================
--- code/branches/gamestates2/data/gui/scripts/KeyBindMenu.lua	(revision 6721)
+++ code/branches/gamestates2/data/gui/scripts/KeyBindMenu.lua	(revision 6722)
@@ -244,5 +244,5 @@
 
 function P.KeyBindBackButton_clicked(e)
-    hideGUI("KeyBindMenu")
+    hideMenuSheet("KeyBindMenu")
 end
 
Index: code/branches/gamestates2/data/gui/scripts/MainMenu.lua
===================================================================
--- code/branches/gamestates2/data/gui/scripts/MainMenu.lua	(revision 6721)
+++ code/branches/gamestates2/data/gui/scripts/MainMenu.lua	(revision 6722)
@@ -9,17 +9,17 @@
 
 function P.SingleplayerButton_clicked(e)
-    showGUI("SingleplayerMenu", true)
+    showMenuSheet("SingleplayerMenu", true)
 end
 
 function P.MultiplayerButton_clicked(e)
-    showGUI("MultiplayerMenu", true)
+    showMenuSheet("MultiplayerMenu", true)
 end
 
 function P.SettingsButton_clicked(e)
-    showGUI("SettingsMenu", true)
+    showMenuSheet("SettingsMenu", true)
 end
 
 function P.CreditsButton_clicked(e)
-    showGUI("CreditsMenu", true)
+    showMenuSheet("CreditsMenu", true)
 end
 
Index: code/branches/gamestates2/data/gui/scripts/MouseControlsMenu.lua
===================================================================
--- code/branches/gamestates2/data/gui/scripts/MouseControlsMenu.lua	(revision 6721)
+++ code/branches/gamestates2/data/gui/scripts/MouseControlsMenu.lua	(revision 6722)
@@ -95,5 +95,5 @@
 
 function P.MouseControlsBackButton_clicked(e)
-    hideGUI(P.name)
+    hideMenuSheet(P.name)
 end
 
Index: code/branches/gamestates2/data/gui/scripts/MultiplayerMenu.lua
===================================================================
--- code/branches/gamestates2/data/gui/scripts/MultiplayerMenu.lua	(revision 6721)
+++ code/branches/gamestates2/data/gui/scripts/MultiplayerMenu.lua	(revision 6722)
@@ -62,10 +62,10 @@
         orxonox.LevelManager:getInstance():setDefaultLevel(choice:getText() .. ".oxw")
         orxonox.execute(multiplayerMode)
-        hideAllGUIs()
+        hideAllMenuSheets()
     end
 end
 
 function P.MultiplayerBackButton_clicked(e)
-    hideGUI(P.name)
+    hideMenuSheet(P.name)
 end
 
Index: code/branches/gamestates2/data/gui/scripts/MultiplayerOptionsMenu.lua
===================================================================
--- code/branches/gamestates2/data/gui/scripts/MultiplayerOptionsMenu.lua	(revision 6721)
+++ code/branches/gamestates2/data/gui/scripts/MultiplayerOptionsMenu.lua	(revision 6722)
@@ -4,5 +4,5 @@
 
 function P.MultiplayerOptionsBackButton_clicked(e)
-    hideGUI(P.name)
+    hideMenuSheet(P.name)
 end
 
Index: code/branches/gamestates2/data/gui/scripts/SettingsMenu.lua
===================================================================
--- code/branches/gamestates2/data/gui/scripts/SettingsMenu.lua	(revision 6721)
+++ code/branches/gamestates2/data/gui/scripts/SettingsMenu.lua	(revision 6722)
@@ -4,21 +4,21 @@
 
 function P.SettingsGameplayButton_clicked(e)
-    showGUI("GameplayMenu", true)
+    showMenuSheet("GameplayMenu", true)
 end
 
 function P.SettingsMultiplayerOptionsButton_clicked(e)
-    showGUI("MultiplayerOptionsMenu", true)
+    showMenuSheet("MultiplayerOptionsMenu", true)
 end
 
 function P.SettingsControlsButton_clicked(e)
-    showGUI("ControlsMenu", true)
+    showMenuSheet("ControlsMenu", true)
 end
 
 function P.SettingsGraphicsButton_clicked(e)
-    showGUI("GraphicsMenu", true)
+    showMenuSheet("GraphicsMenu", true)
 end
 
 function P.SettingsAudioButton_clicked(e)
-    showGUI("AudioMenu", true)
+    showMenuSheet("AudioMenu", true)
 end
 
@@ -29,5 +29,5 @@
 
 function P.SettingsBackButton_clicked(e)
-    hideGUI(P.name)
+    hideMenuSheet(P.name)
 end
 
Index: code/branches/gamestates2/data/gui/scripts/SingleplayerMenu.lua
===================================================================
--- code/branches/gamestates2/data/gui/scripts/SingleplayerMenu.lua	(revision 6721)
+++ code/branches/gamestates2/data/gui/scripts/SingleplayerMenu.lua	(revision 6722)
@@ -34,10 +34,10 @@
         orxonox.LevelManager:getInstance():setDefaultLevel(choice:getText() .. ".oxw")
         orxonox.execute("startGame")
-        hideAllGUIs()
+        hideAllMenuSheets()
     end
 end
 
 function P.SingleplayerBackButton_clicked(e)
-    hideGUI(P.name)
+    hideMenuSheet(P.name)
 end
 
Index: code/branches/gamestates2/src/libraries/core/GUIManager.h
===================================================================
--- code/branches/gamestates2/src/libraries/core/GUIManager.h	(revision 6721)
+++ code/branches/gamestates2/src/libraries/core/GUIManager.h	(revision 6722)
@@ -75,6 +75,6 @@
 
         void loadGUI(const std::string& name);
-        static void showGUI(const std::string& name, bool hidePrevious=false, bool showCursor=true);
-        void showGUIExtra(const std::string& name, const std::string& ptr, bool hidePrevious=false, bool showCursor=true);
+        static void showGUI(const std::string& name, bool bHidePrevious = false);
+        void showGUIExtra(const std::string& name, const std::string& ptr, bool bHidePrevious = false);
         static void hideGUI(const std::string& name);
         void keyESC();
Index: code/branches/gamestates2/src/orxonox/gamestates/GSMainMenu.cc
===================================================================
--- code/branches/gamestates2/src/orxonox/gamestates/GSMainMenu.cc	(revision 6721)
+++ code/branches/gamestates2/src/orxonox/gamestates/GSMainMenu.cc	(revision 6722)
@@ -85,5 +85,5 @@
     {
         // show main menu
-        GUIManager::getInstance().showGUI("MainMenu", true, GraphicsManager::getInstance().isFullScreen());
+        GUIManager::getInstance().showGUI("MainMenu", true);
         GUIManager::getInstance().setCamera(this->camera_);
         GUIManager::getInstance().setBackground("MainMenuBackground");
Index: code/branches/gamestates2/src/orxonox/overlays/GUISheet.cc
===================================================================
--- code/branches/gamestates2/src/orxonox/overlays/GUISheet.cc	(revision 6721)
+++ code/branches/gamestates2/src/orxonox/overlays/GUISheet.cc	(revision 6722)
@@ -65,5 +65,5 @@
     void GUISheet::show()
     {
-        GUIManager::showGUI(this->script_, this->bHidePrevious_, this->bShowCursor_);
+        GUIManager::showGUI(this->script_, this->bHidePrevious_);
     }
 

Index: code/branches/gamestates2/src/libraries/core/GUIManager.cc
===================================================================
--- code/branches/gamestates2/src/libraries/core/GUIManager.cc	(revision 6721)
+++ code/branches/gamestates2/src/libraries/core/GUIManager.cc	(revision 6722)
@@ -226,9 +226,8 @@
 
         The function executes the Lua function with the same name in case the GUIManager is ready.
-        For more details check out loadGUI_2.lua where the function presides.
-    */
-    /*static*/ void GUIManager::showGUI(const std::string& name, bool hidePrevious, bool showCursor)
-    {
-        GUIManager::getInstance().executeCode("showGUI(\"" + name + "\", " + multi_cast<std::string>(hidePrevious) + ", " + multi_cast<std::string>(showCursor) + ")");
+    */
+    /*static*/ void GUIManager::showGUI(const std::string& name, bool bHidePrevious)
+    {
+        GUIManager::getInstance().executeCode("showMenuSheet(\"" + name + "\", " + multi_cast<std::string>(bHidePrevious) + ")");
     }
 
@@ -237,7 +236,7 @@
         Hack-ish. Needed for GUIOverlay.
     */
-    void GUIManager::showGUIExtra(const std::string& name, const std::string& ptr, bool hidePrevious, bool showCursor)
-    {
-        this->executeCode("showGUI(\"" + name + "\", " + multi_cast<std::string>(hidePrevious) + ", " + multi_cast<std::string>(showCursor) + ", " + ptr + ")");
+    void GUIManager::showGUIExtra(const std::string& name, const std::string& ptr, bool bHidePrevious)
+    {
+        this->executeCode("showMenuSheet(\"" + name + "\", " + multi_cast<std::string>(bHidePrevious) + ", " + ptr + ")");
     }
 
@@ -250,5 +249,5 @@
     /*static*/ void GUIManager::hideGUI(const std::string& name)
     {
-        GUIManager::getInstance().executeCode("hideGUI(\"" + name + "\")");
+        GUIManager::getInstance().executeCode("hideMenuSheet(\"" + name + "\")");
     }
 